==> ejc-cost-api-3.0.0-20201218.033103-26-sources.jar: com/ejianc/business/cost/vo/SubjectReportsVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 科目明细数据展示
 * 
 * @author sunyj
 * 
 */
public class SubjectReportsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String subjectName; // 科目名称
    private String subjectCode; // 科目编码
    private String happenDate; // 发生日期
    private Long parentId; // parent_id
    private BigDecimal happenMny; // 发生成本

    private BigDecimal happenMnySum; // 截止上期发生成本


    private List<SubjectReportsVO> children; //子集数据

    public BigDecimal getHappenMnySum() {
        return happenMnySum;
    }

    public void setHappenMnySum(BigDecimal happenMnySum) {
        this.happenMnySum = happenMnySum;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getHappenDate() {
        return happenDate;
    }

    public void setHappenDate(String happenDate) {
        this.happenDate = happenDate;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }

    public List<SubjectReportsVO> getChildren() {
        return children;
    }

    public void setChildren(List<SubjectReportsVO> children) {
        this.children = children;
    }
}

==> ejc-cost-api-3.0.0-20201219.071933-29-sources.jar: com/ejianc/business/cost/vo/SubjectReportsVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 科目明细数据展示
 * 
 * @author sunyj
 * 
 */
public class SubjectReportsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String subjectName; // 科目名称
    private String subjectCode; // 科目编码
    private String happenDate; // 发生日期
    private Long parentId; // parent_id
    private BigDecimal happenMny; // 发生成本
    private java.lang.String detailIndex; // 序号  1   1.1
    private BigDecimal happenMnySum; // 截止上期发生成本
    private Integer number;


    private List<SubjectReportsVO> children; //子集数据

    public Integer getNumber() {
        return number;
    }

    public void setNumber(Integer number) {
        this.number = number;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public BigDecimal getHappenMnySum() {
        return happenMnySum;
    }

    public void setHappenMnySum(BigDecimal happenMnySum) {
        this.happenMnySum = happenMnySum;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getHappenDate() {
        return happenDate;
    }

    public void setHappenDate(String happenDate) {
        this.happenDate = happenDate;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }

    public List<SubjectReportsVO> getChildren() {
        return children;
    }

    public void setChildren(List<SubjectReportsVO> children) {
        this.children = children;
    }
}
